pub enum UnindexedStrategy {
Skip,
Walk,
}Expand description
Whether the planner should walk for files not present in the index snapshot.
Variants
Skip
Return only index-narrowed candidates. No filesystem walk.
Walk
Walk to discover files not yet indexed and merge them into results.