pub struct SearchQuery { /* private fields */ }Implementations
Sourceimpl SearchQuery
impl SearchQuery
Sourcepub fn build_matcher(&self) -> Result<RegexMatcher, SearchError>
pub fn build_matcher(&self) -> Result<RegexMatcher, SearchError>
Builds a regex matcher from the compiled patterns and options.
Errors
Returns SearchError::RegexBuild if pattern compilation fails.
pub fn build_searcher( &self, line_number: bool, max_matches: Option<usize>, include_context: bool, ) -> Searcher
Sourceimpl SearchQuery
impl SearchQuery
Sourcepub fn new(
patterns: &[String],
opts: SearchOptions,
) -> Result<Self, SearchError>
pub fn new( patterns: &[String], opts: SearchOptions, ) -> Result<Self, SearchError>
Creates a new search query from patterns and options.
Errors
Returns SearchError::EmptyPatterns if the pattern list is empty.
pub fn patterns(&self) -> &[String]
pub const fn opts(&self) -> &SearchOptions