SearchQuery

Struct SearchQuery 

pub struct SearchQuery {
    pub patterns: Vec<String>,
    pub opts: SearchOptions,
    pub matcher: OnceLock<RegexMatcher>,
    pub searcher_cache: Mutex<Option<((bool, Option<usize>, usize, usize), Searcher)>>,
}

Fields

patterns: Vec<String>opts: SearchOptionsmatcher: OnceLock<RegexMatcher>searcher_cache: Mutex<Option<((bool, Option<usize>, usize, usize), Searcher)>>

Implementations

Source

impl SearchQuery

pub fn build_matcher(&self) -> Result<RegexMatcher, SearchError>

Builds a regex matcher from the compiled patterns and options.

Errors

Returns SearchError::RegexBuild if pattern compilation fails.

pub fn build_searcher( &self, line_number: bool, max_matches: Option<usize>, include_context: bool, ) -> Searcher

Source

impl SearchQuery

pub fn new( patterns: &[String], opts: SearchOptions, ) -> Result<Self, SearchError>

Creates a new search query from patterns and options.

Errors

Returns SearchError::EmptyPatterns if the pattern list is empty.

pub fn patterns(&self) -> &[String]