pub struct StoreMeta {
pub version: u32,
pub corpus: CorpusMeta,
pub walk: WalkMeta,
pub filters: FilterMeta,
pub indexes: Vec<IndexKind>,
}Expand description
Persistent store manifest (.sift/meta.json).
Fields
version: u32corpus: CorpusMetawalk: WalkMetafilters: FilterMetaindexes: Vec<IndexKind>Implementations
Sourceimpl StoreMeta
impl StoreMeta
Sourcepub const fn new(
corpus: CorpusMeta,
walk: WalkMeta,
filters: FilterMeta,
indexes: Vec<IndexKind>,
) -> Self
pub const fn new( corpus: CorpusMeta, walk: WalkMeta, filters: FilterMeta, indexes: Vec<IndexKind>, ) -> Self
Create a new StoreMeta with the current store version.
Sourcepub fn index_config(&self) -> IndexConfig<'_>
pub fn index_config(&self) -> IndexConfig<'_>
Map persisted metadata to a runtime index build configuration.
Sourcepub fn matches_search_filter(&self, filter: &CandidateFilter) -> bool
pub fn matches_search_filter(&self, filter: &CandidateFilter) -> bool
Whether the search-time filter matches the walk and visibility stored in meta.