Fast indexed regex search over codebases — core engine.
Walking: WalkBuilder from the ignore crate.
Re-exports
pub use grep::GrepRun;pub use candidate::Candidate;pub use query::CandidateRequirement;pub use query::QueryFlags;pub use query::QueryPlanner;pub use query::QuerySpec;
Modules
Structs
- Candidate
Filter - Candidate
Filter Config - Column
Limit - Corpus
Meta - Which corpus this store indexes.
- Corpus
Spec - Description of a corpus to index.
- FileId
- Filter
Meta - Ignore and visibility rules in effect when the index was built.
- Glob
Config - Ignore
Config - Ignore
Sources - Index
Config - Configuration for building or updating an index over a corpus.
- IndexId
- Index
Store - Index lifecycle orchestrator backed by a [
SnapshotStore] for atomic persistence and coordination. - Index
Walk Options - Filesystem walk behavior for index builds and updates.
- Indexes
- Registry of opened indexes read from a snapshot store.
- Line
Style Flags - Match
- Pattern
Compiler - Query
Plan Output - Search
Collection - Optional artifacts gathered during search beyond primary output.
- Search
Line Style - Search
Match Flags - Search
Options - Search
Outcome - Search
Output - Search
Query - Search
Record Style - Search
Separators - Search
Stats - Store
Meta - Persistent store manifest (
.sift/meta.json). - Trigram
Index - TypeDef
- Visibility
Config - Walk
- Walk is a recursive directory iterator over file paths in one or more directories.
- Walk
Builder - WalkBuilder builds a recursive directory iterator.
- Walk
Meta - Filesystem walk behavior used when the index was built.
- Walk
Options
Enums
- Binary
Mode - Case
Mode - Color
Choice - Column
Overflow - Corpus
Kind - Whether the index was built from a directory or a single file.
- Error
- Top-level umbrella error for all core operations.
- Filename
Mode - Hidden
Mode - Index
- An opened index instance, used for search-time dispatch.
- Index
Error - Errors specific to the index registry layer.
- Index
Kind - Tag identifying an index kind for lifecycle dispatch (build, open, update).
- Link
Traversal - Match
Emission Mode - Output
Emission - Passthru
Mode - Path
Display - Plan
Mode - How an index query plan resolves candidates.
- Record
Terminator - Search
Error - Search
Mode - Search
Output Format - Trigram
Index Error - Errors specific to opening or persisting a trigram index.
- Zero
Count Mode